@@ -5,6 +5,34 @@ import time
 logger = logging.getLogger(__name__)
 
 
+def humanized_wait_duration(min_time: float, max_time: float | None = None, multiplier: float = 2) -> float:
+    """Generate a humanized wait time with random variations.
+
+    Args:
+        min_time: Minimum wait time in seconds
+        max_time: Maximum wait time in seconds. If None, uses min_time * multiplier
+        multiplier: Multiplier for max_time when max_time is None
+
+    Returns:
+        float: The actual wait time in seconds
+    """
+    # Add a small random delay (0-1 seconds)
+    # trunk-ignore(bandit/B311)
+    small_delay = random.random()
+
+    # Calculate the main wait time
+    if max_time is None:
+        max_time = min_time * multiplier
+
+    # trunk-ignore(bandit/B311)
+    main_wait = random.uniform(min_time, max_time)
+
+    # Total wait time
+    actual_wait = small_delay + main_wait
+
+    return actual_wait
+
+
 def humanized_wait(
     min_wait: int, max_wait: int | None = None, multiply_factor: float = 2, wait_addendum: float = 0.25
 ) -> None:
@@ -41,18 +69,33 @@ def humanized_wait(
     if wait_addendum < 0:
         raise ValueError("wait_addendum must be non-negative")
 
-    # Calculate wait time
-    max_wait = int(max_wait or min_wait * multiply_factor)
-    actual_wait = wait_addendum + random.random() + random.randint(min_wait, max_wait)  # nosec
+    time.sleep(humanized_wait_duration(min_time=min_wait, max_time=max_wait, multiplier=multiply_factor))
 
-    # Log wait time
-    logger.debug(f"Waiting for {actual_wait:.2f} seconds")
 
-    try:
-        time.sleep(actual_wait)
-    except KeyboardInterrupt:
-        logger.warning("Wait interrupted by user")
-        raise
-    except Exception as e:
-        logger.error(f"Error during wait: {str(e)}")
-        raise
+def duration_to_type(value: str, speed: int = 100) -> float:
+    """Calculate the duration needed to type a text at a given speed.
+
+    Args:
+        value: The text to type
+        speed: Typing speed in words per minute (default: 100)
+
+    Returns:
+        float: Duration in seconds needed to type the text
+    """
+    # Average word length is 5 characters
+    avg_word_length = 5
+
+    # Calculate number of words (roughly)
+    num_words = len(value) / avg_word_length
+
+    # Calculate time in minutes
+    time_minutes = num_words / speed
+
+    # Convert to seconds
+    time_seconds = time_minutes * 60
+
+    # Add some randomness (±20%)
+    # trunk-ignore(bandit/B311)
+    variation = random.uniform(0.8, 1.2)
+
+    return time_seconds * variation
